from ansible_vault.cli import main


raise SystemExit(main())
